@@ -22,6 +22,7 @@ void cutcomment(char*  text)
 {
   char* cp;
   int laenge;
+
   cp=strchr(text,'#');
   if (cp!=0)
     *cp=0;
@@ -49,23 +50,25 @@ int yesno( char*  value)
     return 0;
 }
 
-int getsubparam( char*  parameter, 
-                 int n, 
-                char*  subparam,  int size_subparam)
+int getsubparam_delim(char*  parameter, 
+                      int n, 
+                      char*  subparam,  int size_subparam,
+                      char delim)
 {
   int j;
   char* cp;
   char* cp2;
   int size;
+
   cp=(char*)parameter;
   subparam[0]=0;
   for (j=1; j<n; j++)
   {
-    if (!strchr(cp,','))
+    if (!strchr(cp,delim))
       return 0;
-    cp=strchr(cp,',')+1;
+    cp=strchr(cp,delim)+1;
   }
-  cp2=strchr(cp,',');
+  cp2=strchr(cp,delim);
   if (cp2)
     size=cp2-cp;
   else
@@ -76,12 +79,20 @@ int getsubparam( char*  parameter,
   return 1;
 }
 
+int getsubparam(char*  parameter, 
+                int n, 
+                char*  subparam,  int size_subparam)
+{
+  return getsubparam_delim(parameter, n, subparam, size_subparam, ',');
+}
+
 int splitline( char*  source, 
               char*  name,  int size_name,
 	      char*  value,  int size_value)
 {
   char* equalchar;
   int n;
+
   equalchar=strchr(source,'=');
   value[0]=0;
   name[0]=0;
@@ -93,8 +104,8 @@ int splitline( char*  source,
     n=equalchar-source;
     if (n>0)
     {
-      if (n>size_name)
-        n=size_name;
+      if (n>size_name-1)
+        n=size_name-1;
       strncpy(name,source,n);
       name[n]=0;
       cutspaces(name);
@@ -109,6 +120,7 @@ int gotosection(FILE* file,  char*  name)
   char line[PATH_MAX+32];
   int Length;
   char* posi;
+
   fseek(file,0,SEEK_SET);
   while (fgets(line,sizeof(line),file))
   {
@@ -132,6 +144,7 @@ int my_getline(FILE* file,
 {
   char line[PATH_MAX+32];
   int Length;
+
   while (fgets(line,sizeof(line),file))
   {
     cutcomment(line);
