@@ -20,8 +20,13 @@ Either version 2 of the License, or (at your option) any later version.
 /*  Gets a single parameter from a list of parameters wich uses colons
 to separate them. Returns 1 if successful. */
 
-int getsubparam( char*  parameter, 
-                 int n, 
+int getsubparam_delim(char*  parameter,
+                      int n,
+                      char*  subparam,  int size_subparam, 
+                      char delim);
+
+int getsubparam(char*  parameter, 
+                int n, 
                 char*  subparam,  int size_subparam);
 
 
