@@ -27,6 +27,6 @@ int islocked( char*  filename);
 
 /* Unlocks a file */
 
-int unlock( char*  filename);
+int unlockfile( char*  filename);
 
 #endif
