@@ -17,6 +17,10 @@ Either version 2 of the License, or (at your option) any later version.
 
 char whitelist[256];	// Filename of the white-list
 
+/* Used with >= 3.1x */
+int inwhitelist_q(char* msisdn, char *queuename);
+
+/* Used with < 3.1x */
 int inwhitelist(char* msisdn);
 
 #endif
